@@ -43,7 +43,7 @@
 #include <Plasma/Corona>
 #include <Plasma/Theme>
 #include <Plasma/Frame>
-
+#include <QDebug>
 #include <qjson/parser.h>
 
 
@@ -113,6 +113,8 @@ void KTranslatoid::constructForm()
 {
     m_graphicsWidget = new QGraphicsWidget(m_extender);
 
+   m_sourceLanguageLabel->setStyleSheet("font: bold 12px");
+   m_destLanguageLabel->setStyleSheet("font: bold 12px");
 
     Plasma::ToolTipContent data;
     data.setMainText(i18n("Translatoid"));
@@ -150,7 +152,7 @@ void KTranslatoid::constructForm()
     pastButton->nativeWidget()->setToolTip(i18n("Paste a selection to translate it"));
     copyButton->nativeWidget()->setToolTip(i18n("Copy the result"));
     clearButton->nativeWidget()->setToolTip(i18n("Clear the source text"));
-    reminderButton->nativeWidget()->setToolTip(i18n("Remember it"));
+    reminderButton->nativeWidget()->setToolTip(i18n("Click here to remind the translation"));
 
     m_sourceLanguageButton->nativeWidget()->setToolTip(i18n("Change source language"));
     m_destLanguageButton->nativeWidget()->setToolTip(i18n("Change destination language"));
@@ -211,8 +213,9 @@ void KTranslatoid::constructForm()
     m_reminderTranslatedText= new Plasma::Label;
     QColor sourceCol = Plasma::Theme::defaultTheme()->color(Plasma::Theme::defaultTheme()->TextColor);
     QColor translatedCol =  Plasma::Theme::defaultTheme()->color(Plasma::Theme::defaultTheme()->TextColor);
-    m_reminderSourceText->setStyleSheet("color:"+sourceCol.name()+";font-weight:bold");
-    m_reminderTranslatedText->setStyleSheet("color:"+translatedCol.name()+";font-weight:bold");
+    
+    m_reminderSourceText->setStyleSheet("color:"+col.name()+";font-weight:bold");
+    m_reminderTranslatedText->setStyleSheet("color:"+col.name());
 
     QGraphicsLinearLayout *reminderLayout = new QGraphicsLinearLayout(Qt::Vertical);
     reminderLayout->setAlignment(m_reminderSourceText,Qt::AlignTop);
@@ -261,7 +264,7 @@ void KTranslatoid::translate()
     QString st = "text="+texte+"&client=t&sl=" + source + "&tl=" + dest;
 
     postData = st.toUtf8();
-
+qDebug()<<postData;
     
     if (m_job) {
         disconnect(m_job, 0, this, 0);
@@ -299,60 +302,67 @@ void KTranslatoid::httpDataReceived(KIO::Job *job, QByteArray data)
 void KTranslatoid::done()
 {
     setBusy(false);
-    m_job = 0;
-    //kDebug() << "HTTP Request done." << m_data;
-
-    QString text;
-    text = text.fromUtf8(m_data);
-    /* m_data.clear();
-    kDebug() << "All data is read.";*/
-
-    QVariantMap sentences;
-    QVariantList dict;
+      m_job = 0;
+     //kDebug() << "HTTP Request done." << m_data;
+ 
+    if (m_data.at(m_data.size()-6) == ',' &&
+    m_data.at(m_data.size()-7) == ','){
+       m_data.insert((m_data.size()-6), '"');
+       m_data.insert((m_data.size()-6), '"');
+    }
+     QString text;
+    QString dictionnary;
     QString textToReturn = QString();
-    QJson::Parser parser;
-    bool ok;
-    QVariantMap result = parser.parse(m_data,&ok).toMap();
+     text = text.fromUtf8(m_data);
+    kDebug() << text;
+     /* m_data.clear();
+     kDebug() << "All data is read.";*/
+ 
 
-    if (!ok) {
-        kDebug()<<"An error occured during parsing";
-        return;
-    }
+     QJson::Parser parser;
+     bool ok;
+    QVariantList result = parser.parse(m_data,&ok).toList();
+ 
+     if (!ok) {
+         kDebug()<<"An error occured during parsing";
+        m_destText->setText(text);
+         return;
+     }
+ 
 
-    if (result.contains("sentences"))
-        sentences = result["sentences"].toList().at(0).toMap();
+    foreach ( QVariant map, result)
+     {
 
-    if (result.contains("dict"))
-        dict = result["dict"].toList();
+        if ( map.type() == QVariant::List)
+         {
+           foreach ( QVariant map2, map.toList())
+             {
+                if ( map2.type() == QVariant::List)
+                 {
 
-    if ( sentences.contains("trans"))
-        textToReturn += sentences["trans"].toString()+"<hr/>";
+                    bool ishow = true;
+                    foreach ( QVariant var, map2.toList()){
+                        if ( (var.type() == QVariant::String) && ishow){
+                            ishow=false; 
+                            dictionnary+=("<b>" + var.toString() + "</b><br/>\n");
+                            }
+                        if ( var.type() == QVariant::List){
+                            foreach ( QVariant var2, var.toList()){
+                                if ( var2.type() == QVariant::String)
+                                    dictionnary+=(var2.toString()+"<br/>\n");
+                            }
+                        }
+                     }
+                    dictionnary+="<hr/>\n";
+                 }
+             }
+         }
+     }
+     textToReturn += dictionnary;
 
-
-    QString dictionnary=QString();
-    foreach ( QVariant var, dict)
-    {
-
-        if ( var.type() == QVariant::Map)
-        {
-            foreach ( QVariant map, var.toMap())
-            {
-                if ( map.type() == QVariant::String)
-                    dictionnary+="<b>"+map.toString()+"</b><br/>";
-
-                if ( map.type() == QVariant::List)
-                {
-                    foreach ( QVariant word, map.toList())
-                    {
-                        dictionnary+=( word.toString() + " ");
-                    }
-                }
-            }
-        }
-    }
-
-    textToReturn += dictionnary;
-    m_destText->setText(textToReturn);
+    
+    m_destText->setText("<html><body>" + textToReturn + "</body></html>");
+    //m_destText->setHtml(textToReturn);
 }
 
 //===================================================================================
@@ -619,8 +629,8 @@ void KTranslatoid::showReminder()
     int id = (qrand()%(m_reminder->count())) + 1;
 
 
-    m_reminderSourceText->setText("("+m_reminder->lgSource(id)+") "+m_reminder->source(id));
-    m_reminderTranslatedText->setText("("+m_reminder->lgTranslated(id)+") "+m_reminder->translated(id));
+    m_reminderSourceText->setText(m_reminder->source(id));
+    m_reminderTranslatedText->setText(m_reminder->translated(id));
     m_reminderExtender->adjustSize();
 
 
